==> msgraph-sdk-android-1.1.0-sources.jar: com/microsoft/graph/extensions/WorkbookFunctionsEcma_CeilingRequestBuilder.java <==
// ------------------------------------------------------------------------------
// Copyright (c) Microsoft Corporation.  All Rights Reserved.  Licensed under the MIT License.  See License in the project root for license information.
// ------------------------------------------------------------------------------

package com.microsoft.graph.extensions;

import com.microsoft.graph.concurrency.*;
import com.microsoft.graph.core.*;
import com.microsoft.graph.extensions.*;
import com.microsoft.graph.http.*;
import com.microsoft.graph.generated.*;
import com.microsoft.graph.options.*;
import com.microsoft.graph.serializer.*;

import java.util.Arrays;
import java.util.List;

// This file is available for extending, afterwards please submit a pull request.

/**
 * The class for the Workbook Functions Ecma_Ceiling Request Builder.
 */
public class WorkbookFunctionsEcma_CeilingRequestBuilder extends BaseWorkbookFunctionsEcma_CeilingRequestBuilder implements IWorkbookFunctionsEcma_CeilingRequestBuilder {

    /**
     * The request builder for this WorkbookFunctionsEcma_Ceiling
     *
     * @param requestUrl The request url
     * @param client The service client
     * @param requestOptions The options for this request
     */
    public WorkbookFunctionsEcma_CeilingRequestBuilder(final String requestUrl, final IBaseClient client, final List<Option> requestOptions, final com.google.gson.JsonElement number, final com.google.gson.JsonElement significance) {
        super(requestUrl, client, requestOptions, number, significance);
    }
}

==> msgraph-sdk-android-1.3.1-sources.jar: com/microsoft/graph/extensions/WorkbookFunctionsEcma_CeilingRequestBuilder.java <==
// ------------------------------------------------------------------------------
// Copyright (c) Microsoft Corporation.  All Rights Reserved.  Licensed under the MIT License.  See License in the project root for license information.
// ------------------------------------------------------------------------------

package com.microsoft.graph.extensions;

import com.microsoft.graph.concurrency.*;
import com.microsoft.graph.core.*;
import com.microsoft.graph.extensions.*;
import com.microsoft.graph.http.*;
import com.microsoft.graph.generated.*;
import com.microsoft.graph.options.*;
import com.microsoft.graph.serializer.*;

import java.util.Arrays;
import java.util.EnumSet;

// This file is available for extending, afterwards please submit a pull request.

/**
 * The class for the Workbook Functions Ecma_Ceiling Request Builder.
 */
public class WorkbookFunctionsEcma_CeilingRequestBuilder extends BaseWorkbookFunctionsEcma_CeilingRequestBuilder implements IWorkbookFunctionsEcma_CeilingRequestBuilder {

    /**
     * The request builder for this WorkbookFunctionsEcma_Ceiling
     *
     * @param requestUrl The request url
     * @param client The service client
     * @param requestOptions The options for this request
     */
    public WorkbookFunctionsEcma_CeilingRequestBuilder(final String requestUrl, final IBaseClient client, final java.util.List<Option> requestOptions, final com.google.gson.JsonElement number, final com.google.gson.JsonElement significance) {
        super(requestUrl, client, requestOptions, number, significance);
    }
}
